aboutsummaryrefslogtreecommitdiff
path: root/src/drivers/i2c/sx9310/chip.h
diff options
context:
space:
mode:
authorFurquan Shaikh <furquan@google.com>2019-04-10 10:22:06 -0700
committerFurquan Shaikh <furquan@google.com>2019-04-12 02:14:51 +0000
commitaea9871a62173264fd4878486c49df5f5d4f8cfc (patch)
treeeaf2104bb3b89e73a0961b0eda06a74999034480 /src/drivers/i2c/sx9310/chip.h
parent55208409bc18a9ed6c150bc85e2191bc383e306a (diff)
drivers/i2c/sx9310: Add support for GPIO IRQ
This change adds support for mainboards to use GPIO IRQ instead of IOAPIC to accomodate for cases where IOAPIC routing might not be available for certain pads. BUG=b:129794308 Change-Id: I3e2bb4280303cea177cc0c803d29140731e2b44a Signed-off-by: Furquan Shaikh <furquan@google.com> Reviewed-on: https://review.coreboot.org/c/coreboot/+/32273 Reviewed-by: Aaron Durbin <adurbin@chromium.org> Reviewed-by: Duncan Laurie <dlaurie@chromium.org> Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
Diffstat (limited to 'src/drivers/i2c/sx9310/chip.h')
-rw-r--r--src/drivers/i2c/sx9310/chip.h18
1 files changed, 14 insertions, 4 deletions
diff --git a/src/drivers/i2c/sx9310/chip.h b/src/drivers/i2c/sx9310/chip.h
index 2799f5bb99..c99a8a1539 100644
--- a/src/drivers/i2c/sx9310/chip.h
+++ b/src/drivers/i2c/sx9310/chip.h
@@ -22,10 +22,20 @@
#define REGISTER(NAME) uint8_t NAME
struct drivers_i2c_sx9310_config {
- const char *desc; /* Device Description */
- unsigned int uid; /* ACPI _UID */
- enum i2c_speed speed; /* Bus speed in Hz, default is I2C_SPEED_FAST */
- struct acpi_irq irq; /* Interrupt */
+ /* Device Description */
+ const char *desc;
+
+ /* ACPI _UID */
+ unsigned int uid;
+
+ /* Bus speed in Hz, default is I2C_SPEED_FAST */
+ enum i2c_speed speed;
+
+ /* Use GPIO-based interrupt instead of IO-APIC */
+ struct acpi_gpio irq_gpio;
+
+ /* IO-APIC interrupt */
+ struct acpi_irq irq;
#include "registers.h"
};